@@ -1,12 +1,12 @@
 import lab as B
 
+from ..constant import Constant, Zero
 from ..diagonal import Diagonal
-from ..matrix import Dense
-from ..constant import Zero, Constant
-from ..triangular import LowerTriangular, UpperTriangular
-from ..lowrank import LowRank
-from ..woodbury import Woodbury
 from ..kronecker import Kronecker
+from ..lowrank import LowRank
+from ..matrix import Dense
+from ..triangular import LowerTriangular, UpperTriangular
+from ..woodbury import Woodbury
 
 __all__ = []
 
@@ -53,4 +53,4 @@ def negative(a: Woodbury):
 
 @B.dispatch
 def negative(a: Kronecker):
-    return Kronecker(B.negative(a.left), a.right)
\ No newline at end of file
+    return Kronecker(B.negative(a.left), a.right)
