@@ -1,7 +1,7 @@
 import lab as B
 from wbml.warning import warn_upmodule
 
-from ..constant import Zero, Constant
+from ..constant import Constant, Zero
 from ..diagonal import Diagonal
 from ..kronecker import Kronecker
 from ..matrix import AbstractMatrix, Dense, structured
@@ -48,4 +48,4 @@ def sqrt(a: UpperTriangular):
 
 @B.dispatch
 def sqrt(a: Kronecker):
-    return Kronecker(B.sqrt(a.left), B.sqrt(a.right))
\ No newline at end of file
+    return Kronecker(B.sqrt(a.left), B.sqrt(a.right))
