@@ -8,5 +8,5 @@ from ..util import approx, dense1
 
 
 def test_eye(dense1):
-    approx(B.eye(dense1), np.eye(B.shape(dense1)[0]))
+    approx(B.eye(dense1), np.eye(B.shape_matrix(dense1, 0)))
     assert isinstance(B.eye(dense1), Diagonal)
