@@ -1,11 +1,11 @@
 import lab as B
 import pytest
 
-from matrix import Constant, Dense, Diagonal, Kronecker, LowRank, Woodbury, Zero
-
 # noinspection PyUnresolvedReferences
 from ..util import (
     approx,
+    ConditionalContext,
+    AssertDenseWarning,
     check_un_op,
     const_r,
     dense_r,
@@ -20,16 +20,20 @@ from ..util import (
 )
 
 
-def _check_sum(a):
-    for axis in [None, 0, 1]:
+def _check_sum(a, warn_batch=False):
+    for axis in [None, B.rank(a) - 1, B.rank(a) - 2, -1, -2]:
+        check_un_op(lambda x: B.sum(x, axis=axis), a)
 
-        def sum(a):
-            return B.sum(a, axis=axis)
-
-        check_un_op(sum, a)
+    # Also test summing over the batch dimension!
+    if B.shape_batch(a) != ():
+        for axis in [0, -3]:
+            with ConditionalContext(
+                warn_batch, AssertDenseWarning("over batch dimensions")
+            ):
+                check_un_op(lambda x: B.sum(x, axis=axis), a)
 
     with pytest.raises(ValueError):
-        B.sum(a, axis=2)
+        B.sum(a, axis=5)
 
 
 def test_sum_zero(zero_r):
@@ -57,12 +61,12 @@ def test_sum_ut(ut1):
 
 
 def test_sum_lr(lr_r):
-    _check_sum(lr_r)
+    _check_sum(lr_r, warn_batch=True)
 
 
 def test_sum_wb(wb1):
-    _check_sum(wb1)
+    _check_sum(wb1, warn_batch=True)
 
 
 def test_sum_kron(kron_r):
-    _check_sum(kron_r)
+    _check_sum(kron_r, warn_batch=True)
